<div align="center">

# UVR_resources

---

| Link | Description |
|------|-------------|
| [Model Storage](https://huggingface.co/Politrees/UVR_resources/tree/main) | A model repository on the Hugging Face platform where various machine learning models used in the UVR project can be found and downloaded. |
| [Config Storage](https://github.com/Bebra777228/UVR_resources/tree/main/configs) | A GitHub repository containing configuration files for the UVR project models. These files are necessary for setting up and running the models. |
| [Model Data](https://github.com/Bebra777228/UVR_resources/tree/main/model_data) | A directory on GitHub containing data used for training and testing UVR project models. It includes configuration parameters and model parameters. This data is critical for setting up and optimizing models, ensuring high accuracy and quality in audio processing. |
| [List of Models with Filenames](https://github.com/Bebra777228/UVR_resources/blob/main/model_list_filenames.json) | A JSON file containing a list of all UVR project models with their filenames. This file is useful for automating the download and management of models. |
| [List of Models with File Links](https://github.com/Bebra777228/UVR_resources/blob/main/model_list_links.json) | A JSON file containing a list of all UVR project models with direct links to their files. This file simplifies access to models for downloading and use. |

---

<img src="https://counter.seku.su/cmoe?name=UVR_resources&theme=mbs" /><br>
